import React, {Component} from 'react';
import {DayPilot, DayPilotScheduler} from "daypilot-pro-react";

class Scheduler extends Component {

  constructor(props) {
    super(props);

    this.state = {
      timeHeaders: [{"groupBy":"Month"},{"groupBy":"Day","format":"d"}],
      scale: "Day",
      days: 365,
      startDate: "2021-01-01",
      allowEventOverlap: false,
      timeRangeSelectedHandling: "Enabled",
      onTimeRangeSelected: async (args) => {
        const dp = this.scheduler;
        const modal = await DayPilot.Modal.prompt("Create a new event:", "Event 1");
        dp.clearSelection();
        if (modal.canceled) { return; }
        dp.events.add({
          start: args.start,
          end: args.end,
          id: DayPilot.guid(),
          resource: args.resource,
          text: modal.result
        });
      },
      treeEnabled: true,
    };
  }

  componentDidMount() {

    // load resource and event data
    this.setState({
      resources: [
        {name: "Resource A", id: "A"},
        {name: "Resource B", id: "B"},
        {name: "Resource C", id: "C"},
        {name: "Resource D", id: "D"},
        {name: "Resource E", id: "E"},
        {name: "Resource F", id: "F"},
        {name: "Resource G", id: "G"}
      ],
      events: [
        {
          id: 101,
          text: "Non-blocking background event",
          start: "2021-05-02T00:00:00",
          end: "2021-05-15T00:00:00",
          resource: "B",
          barHidden: true,
          backColor: "#dddddd",
          borderColor: "darker",
          nonBlocking: true,
          line: 0,
          height: 50
        },
        {
          id: 102,
          text: "Non-blocking background event",
          start: "2021-05-02T00:00:00",
          end: "2021-05-15T00:00:00",
          resource: "D",
          barHidden: true,
          backColor: "#dd7e6b",
          borderColor: "darker",
          fontColor: "white",
          nonBlocking: true,
          line: 1,
          height: 20
        },
        {
          id: 2,
          text: "Event 2",
          start: "2021-05-08T00:00:00",
          end: "2021-05-13T00:00:00",
          resource: "B",
          barColor: "#38761d",
          barBackColor: "#93c47d"
        },
        {
          id: 3,
          text: "Event 3",
          start: "2021-05-02T00:00:00",
          end: "2021-05-08T00:00:00",
          resource: "D",
          barColor: "#f1c232",
          barBackColor: "#f1c232"
        },
        {
          id: 4,
          text: "Event 3",
          start: "2021-05-02T00:00:00",
          end: "2021-05-08T00:00:00",
          resource: "F",
          barColor: "#cc0000",
          barBackColor: "#ea9999"
        }
      ]
    });

    this.scheduler.scrollTo("2021-05-01");

  }

  render() {
    var {...config} = this.state;
    return (
      <div>
        <DayPilotScheduler
          {...config}
          ref={component => {
            this.scheduler = component && component.control;
          }}
        />
      </div>
    );
  }
}

export default Scheduler;
